#!/usr/bin/python
#############################################################################
# Name:         sshagent.py
# Purpose:      A configurable SSH agent utility for ZOPE3.
#               Bootstrap actions
# Maintainer:   Torsten Kurbad <t.kurbad@iwm-kmrc.de>
# Copyright:    (c) iwm-kmrc.de KMRC - Knowledge Media Research Center
# License:      GPLv2
#############################################################################
__docformat__ = 'restructuredtext'

import transaction

from zope.component import queryUtility
from zope.app.appsetup import IDatabaseOpenedEvent
from zope.app.appsetup import bootstrap

import bop

from sshagent.interfaces import ISSHAgent


@bop.subscriber(IDatabaseOpenedEvent)
def bootstrapSubscriber(event):
    """Subscriber to the IDataBaseOpenedEvent

    Reset (eventually left over) pid and sock arguments of sshagent utility.

    """
    db, connection, root, rootFolder = bootstrap.getInformationFromEvent(event)
    
    sshagent = queryUtility(ISSHAgent,
                            name='SSHAgent',
                            context=rootFolder)

    if sshagent is not None:
        sshagent.pid = None
        sshagent.sock = None
    
    transaction.commit()
    connection.close()
