#!/usr/bin/python
#############################################################################
# Name:         check.py
# Purpose:      A configurable SSH agent utility for ZOPE3.
#               Simple online test facility
# Maintainer:   Torsten Kurbad <t.kurbad@iwm-kmrc.de>
# Copyright:    (c) iwm-kmrc.de KMRC - Knowledge Media Research Center
# License:      GPLv2
#############################################################################
__docformat__ = 'restructuredtext'

from zope.interface import implements
from zope.security.proxy import removeSecurityProxy
from sshagent.interfaces import ICheckSSHAgent


class CheckSSHAgent(object):
    """Test SSHAgent utility configuration."""

    implements(ICheckSSHAgent)

    def __init__(self, context):
        self.context = context
    
    def checkSSHAgent(self):
        """Perform a series of test actions (start agent, add keys, ...)."""
        self.report = []
        util = removeSecurityProxy(self.context)
        self.report.append("... starting check")

        self.report.append("... parameters:")
        self.report.append("... ssh-agent       = %s" % util.ssh_agent)
        self.report.append("... ssh-add         = %s" % util.ssh_add)
        self.report.append("... # of identities = %d" % len(util.identities))

        try:
            util.callAgent()
            self.report.append("... <strong>SSH Agent started successfully.</strong>")
        except:
            self.report.append("... <strong>SSH Agent could not be started.</strong>")
            self.report.append("... <strong>Test FAILED!</strong>")
            return self.report

        try:
            util.addIdentities()
            self.report.append("... <strong>All configured identities added.</strong>")
        except:
            util.killAgent()
            self.report.append("... <strong>The configured identities could not be added.</strong>")
            self.report.append("... <strong>Test FAILED!</strong>")
            return self.report

        try:
            util.clearIdentities()
            self.report.append("... <strong>All identities removed from the agent.</strong>")
        except:
            util.killAgent()
            self.report.append("... <strong>Not all identities could be removed.</strong>")
            self.report.append("... <strong>Test FAILED!</strong>")
            return self.report

        util.killAgent()
        self.report.append("... <strong>Agent stopped.</strong>")
        self.report.append("... <strong>OK</strong>")
        return self.report
